<?php
/* 
 * Plugin Name: Solicitor Core
 * Plugin URI:  http://www.imithemes.com
 * Description: Create Post Types for Solicitor Theme
 * Author:      imithemes
 * Version:     2.5
 * Author URI:  http://www.imithemes.com
 * Licence:     GPLv2
 * License URI: http://www.gnu.org/licenses/gpl-2.0.html
 * Copyright:   (c) 2024 imithemes. All rights reserved
 * Text Domain: solicitor-core
 * Domain Path: /language
 */

// Do not allow direct access to this file.
defined('ABSPATH') or die('No script kiddies please!');
$path = plugin_dir_path(__FILE__);
/* CUSTOM POST TYPES
================================================== */
require_once $path . '/custom-post-types/service-type.php';
require_once $path . '/custom-post-types/event-type.php';
require_once $path . '/custom-post-types/team-type.php';
require_once $path . '/custom-post-types/testimonial-type.php';

/* META BOX PLUGIN EXTENSIONS
================================================== */
require_once $path . '/meta-boxes/meta-box-tabs/meta-box-tabs.php';
require_once $path . '/meta-boxes/mb-term-meta/mb-term-meta.php';
require_once $path . '/meta-boxes/mb-admin-columns/mb-admin-columns.php';
require_once $path . '/meta-boxes/meta-box-conditional-logic/meta-box-conditional-logic.php';
require_once $path . '/meta-boxes/meta-box-show-hide/meta-box-show-hide.php';
require_once($path . '/meta-boxes/term_color_picker.php');
/* EVENT REGISTRATION
====================================================*/
require_once($path . '/meta-boxes/registrant_tickets_field.php');
require_once($path . '/meta-boxes/tickets_clone_fields.php');

/* WIDGETS INCLUDES
================================================== */
require_once $path . '/widgets/custom_category.php';
require_once $path . '/widgets/recent_posts.php';
require_once $path . '/widgets/InstaGram/insta_gallery.php';
require_once $path . '/widgets/Flickr/flickr_widget.php';

/* SHORTCODE ENABLER FOR TEXT WIDGET
================================================== */
add_filter('widget_text', 'do_shortcode');

/* SET LANGUAGE FILE FOLDER
=================================================== */
add_action('after_setup_theme', 'solicitor_core_setup');
function solicitor_core_setup()
{
  load_theme_textdomain('solicitor-core', plugin_dir_path(__FILE__) . '/language');
}


//Add New Custom Menu Option
if (!class_exists('SOLICITOR_Custom_Nav')) {
  class SOLICITOR_Custom_Nav
  {
    public function solicitor_add_nav_menu_meta_boxes()
    {

      add_meta_box(
        'mega_nav_link',
        esc_html__('Mega Menu', 'solicitor'),
        array($this, 'nav_menu_link'),
        'nav-menus',
        'side',
        'low'
      );
    }
    public function nav_menu_link()
    {

      global $_nav_menu_placeholder, $nav_menu_selected_id;
      $_nav_menu_placeholder = 0 > $_nav_menu_placeholder ? $_nav_menu_placeholder - 1 : -1;

      ?>
      <div id="posttype-wl-login" class="posttypediv">
        <div id="tabs-panel-wishlist-login" class="tabs-panel tabs-panel-active">
          <ul id="wishlist-login-checklist" class="categorychecklist form-no-clear">
            <li>
              <label class="menu-item-title">
                <input type="checkbox" class="menu-item-object-id" name="menu-item[<?php echo esc_attr($_nav_menu_placeholder); ?>][menu-item-object-id]" value="<?php echo esc_attr($_nav_menu_placeholder); ?>"> <?php esc_html_e('Create Column', 'solicitor'); ?>
              </label>
              <input type="hidden" class="menu-item-db-id" name="menu-item[<?php echo esc_attr($_nav_menu_placeholder); ?>][menu-item-db-id]" value="0">
              <input type="hidden" class="menu-item-object" name="menu-item[<?php echo esc_attr($_nav_menu_placeholder); ?>][menu-item-object]" value="page">
              <input type="hidden" class="menu-item-parent-id" name="menu-item[<?php echo esc_attr($_nav_menu_placeholder); ?>][menu-item-parent-id]" value="0">
              <input type="hidden" class="menu-item-type" name="menu-item[<?php echo esc_attr($_nav_menu_placeholder); ?>][menu-item-type]" value="">
              <input type="hidden" class="menu-item-title" name="menu-item[<?php echo esc_attr($_nav_menu_placeholder); ?>][menu-item-title]" value="<?php esc_html_e('Column', 'solicitor'); ?>">
              <input type="hidden" class="menu-item-classes" name="menu-item[<?php echo esc_attr($_nav_menu_placeholder); ?>][menu-item-classes]" value="custom_mega_menu">
            </li>
          </ul>
        </div>
        <p class="button-controls">
          <span class="add-to-menu">
            <input type="submit" class="button-secondary submit-add-to-menu right" value="<?php esc_html_e('Add to Menu', 'solicitor'); ?>" name="add-post-type-menu-item" id="submit-posttype-wl-login">
            <span class="spinner"></span>
          </span>
        </p>
      </div>
<?php }
  }
}
$custom_nav = new SOLICITOR_Custom_Nav;
add_action('admin_init', array($custom_nav, 'solicitor_add_nav_menu_meta_boxes'));


if (!function_exists('solicitor_contact_event_manager')) {
  function solicitor_contact_event_manager()
  {
    $event_id = $_POST['itemnumber'];
    $post_type = get_post_type($event_id);
    $event_date = $_POST['event_date'];
    $exhibition_time = (isset($_POST['exhibition_time'])) ? $_POST['exhibition_time'] : '';
    $cost = (isset($_POST['costs']) && $_POST['costs'] != 0) ? $_POST['costs'] : esc_html__('Free', 'solicitor');
    $name = $_POST['name'];
    $lname = $_POST['lastname'];
    $email = $_POST['email'];
    $phone = $_POST['phone'];
    $address = $_POST['address'];
    $notes = $_POST['notes'];
    $ticket_details = (isset($_POST['ticket_details'])) ? $_POST['ticket_details'] : array();
    $event_title = get_the_title($event_id);
    $registration_number = get_post_meta($event_id, 'solicitor_event_registration_number', true);
    $registration_number = ($registration_number == '') ? 0 : $registration_number + 1;
    $reg_post_type = ($post_type == 'event') ? 'event_registrants' : 'exhibition_reg';
    $registrant = array(
      'post_title'    => $name . ' ' . $lname,
      'post_status'   => 'publish',
      'post_author'   => 1,
      'post_type' => $reg_post_type
    );

    // Insert the registrant into the database
    $registrant_id = wp_insert_post($registrant);
    if ($post_type == 'event') {
      wp_set_object_terms($registrant_id, get_the_title($event_id), 'registrant-event');
    }
    $tickets_type_event = get_post_meta($event_id, 'tickets_type', true);
    if (!empty($ticket_details)) {
      $ticket_info = array();
      foreach ($ticket_details as $key => $value) {
        $ticket_info[$key] = $value;
        if (!empty($tickets_type_event)) {
          $tickets_type_event = get_post_meta($event_id, 'tickets_type', true);
          $tickets_type = array();
          foreach ($tickets_type_event as $tickets) {
            if ($tickets[0] != $key) {
              $tickets_type[]  = array($tickets[0], $tickets[1], $tickets[2], $tickets[3]);
            } else {
              $available = $tickets[1];
              $booked_tickets = $tickets[2];
              $new_booked_updated = $booked_tickets + $value;
              $new_available_updated = $available - $value;
              $tickets_type[]  = array($tickets[0], $tickets[1], $new_booked_updated, $tickets[3]);
            }
          }
          delete_post_meta($event_id, 'tickets_type');
          update_post_meta($event_id, 'tickets_type', $tickets_type);
        }
      }
      update_post_meta($registrant_id, 'solicitor_registrant_ticket_type', $ticket_info);
    }
    update_post_meta($registrant_id, 'solicitor_registrant_email', esc_attr($email));
    update_post_meta($registrant_id, 'solicitor_registrant_phone', esc_attr($phone));
    update_post_meta($registrant_id, 'solicitor_registrant_address', esc_attr($address));
    update_post_meta($registrant_id, 'solicitor_registrant_additional_notes', esc_attr($notes));
    update_post_meta($registrant_id, 'solicitor_registrant_event_date', $event_date);
    update_post_meta($registrant_id, 'solicitor_registrant_registration_number', esc_attr($event_id . '-' . $registration_number));
    update_post_meta($registrant_id, 'solicitor_registrant_paid_amount', $cost);
    update_post_meta($event_id, 'solicitor_event_registration_number', $registration_number);
    $event_manager_email = get_post_meta($event_id, 'solicitor_event_manager', true);
    $manager_email = esc_attr($event_manager_email);
    $manager_email = ($manager_email != '') ? $manager_email : get_option('admin_email');
    if ($post_type == "event") {
      $e_subject = esc_html__('Registration for Event', 'solicitor');
    }
    $result['regid'] = esc_attr($event_id . '-' . $registration_number);
    $result['reguser'] = esc_attr($name) . '<br/>' . esc_attr($lname);
    $result['cost'] = esc_attr($cost);
    $result['registrant'] = esc_attr($registrant_id);
    $result = json_encode($result);
    echo $result;
    $e_body = esc_html__("You have been contacted by", "solicitor") . ' ' . $name . ', ' . esc_html__("for", "solicitor") . ' ' . $event_title . PHP_EOL . PHP_EOL;
    $body = esc_html__("Your message has been delivered to Manager for", "solicitor") . ' ' . $event_title . PHP_EOL . PHP_EOL;
    $e_content = '';
    $e_content .= esc_html__("Registration Number:", "solicitor") . ' ' . $event_id . '-' . $registration_number . PHP_EOL . PHP_EOL;
    $e_content .= esc_html__("Date:", "solicitor") . ' ' . $event_date . PHP_EOL . PHP_EOL;
    if ($post_type != "event") {
      $e_content .= esc_html__("Time:", "solicitor") . ' ' . $exhibition_time . PHP_EOL . PHP_EOL;
    }
    $e_content .= esc_html__("Name:", "solicitor") . ' ' . esc_attr($name) . esc_attr($lname) . PHP_EOL . PHP_EOL;
    $e_content .= esc_html__("Email:", "solicitor") . ' ' . esc_attr($email) . PHP_EOL . PHP_EOL;
    $e_content .= esc_html__("Phone:", "solicitor") . ' ' . esc_attr($phone) . PHP_EOL . PHP_EOL;
    $e_content .= esc_html__("Notes:", "solicitor") . ' ' . esc_attr($notes) . PHP_EOL . PHP_EOL;
    $e_content .= esc_html__("Address:", "solicitor") . ' ' . esc_attr($address) . PHP_EOL . PHP_EOL;
    $e_reply = esc_html__("You can contact ", "solicitor") . " " . esc_attr($name) . " " . esc_html__("via email", "solicitor") . ', ' . esc_attr($email);
    $reply = esc_html__("You can contact manager via email", "solicitor") . ', ' . $manager_email;
    $msg = wordwrap($e_body . $e_content . $e_reply, 70);
    $user_msg = wordwrap($body . $e_content . $reply, 70);
    $headers = "From: $email" . PHP_EOL;
    $headers .= "Reply-To: $email" . PHP_EOL;
    $headers .= "MIME-Version: 1.0" . PHP_EOL;
    $headers .= "Content-type: text/plain; charset=utf-8" . PHP_EOL;
    $headers .= "Content-Transfer-Encoding: quoted-printable" . PHP_EOL;
    $user_headers = "From: $manager_email" . PHP_EOL;
    $user_headers .= "Reply-To: $email" . PHP_EOL;
    $user_headers .= "MIME-Version: 1.0" . PHP_EOL;
    $user_headers .= "Content-type: text/plain; charset=utf-8" . PHP_EOL;
    $user_headers .= "Content-Transfer-Encoding: quoted-printable" . PHP_EOL;
    if (mail($manager_email, $e_subject, $msg, $headers) && mail($email, $e_subject, $user_msg, $user_headers)) { } else {
      echo '<div class="alert alert-error">ERROR!</div>';
    }
    die();
  }
  add_action('wp_ajax_nopriv_solicitor_contact_event_manager', 'solicitor_contact_event_manager');
  add_action('wp_ajax_solicitor_contact_event_manager', 'solicitor_contact_event_manager');
}


// Once Click Demo Importer
function OCDI_Plugin_init()
{
  	if( !class_exists( 'OCDI_Plugin' ) ):
    	require_once plugin_dir_path(__FILE__) . '/demo-import/importer/one-click-demo-import.php';
  	endif;
}
add_action( 'plugins_loaded', 'OCDI_Plugin_init' );


function ocdi_import_files() {
  return [
    [
      'import_file_name'             => 'Default',
      'categories'                   => [ 'Default' ],
      'local_import_file'            => plugin_dir_path(__FILE__) . '/demo-import/data/demo1/content.xml',
      'local_import_widget_file'     => plugin_dir_path(__FILE__) . '/demo-import/data/demo1/widgets.json',
      'local_import_customizer_file' => '',
      'local_import_redux'           => [
        [
          'file_path'   => plugin_dir_path(__FILE__) . '/demo-import/data/demo1/theme-options.json',
          'option_name' => 'solicitor_options',
        ],
      ],
      'import_preview_image_url'     => plugin_dir_url(__FILE__) . '/demo-import/data/demo1/screen-image.jpg',
      'preview_url'                  => 'https://demo.imithemes.com/solicitor/',
    ],
  ];
}
add_filter( 'ocdi/import_files', 'ocdi_import_files' );

function ocdi_register_plugins( $plugins ) {
 
  // List of plugins used by all theme demos.
  $theme_plugins = [
    [ 
      'name' => esc_html__('Breadcrumb NavXT', 'solicitor'),
      'slug' => 'breadcrumb-navxt',
      'required'     => true,
    ],
    [ 
      'name' => esc_html__('Pojo Sidebars', 'solicitor'),
      'slug' => 'pojo-sidebars',
      'required'     => true,
    ],
    [ 
      'name' => esc_html__('WooCommerce - excelling eCommerce', 'solicitor'),
      'slug' => 'woocommerce',
      'required'     => true,
    ],
    [ 
      'name' => esc_html__('Meta Box', 'solicitor'),
      'slug' => 'meta-box',
      'required'     => true,
    ],
    [ 
      'name' => esc_html__('Page Builder by SiteOrigin', 'solicitor'),
      'slug' => 'siteorigin-panels',
      'required'     => true,
    ],
    [ 
      'name' => esc_html__('SiteOrigin Widgets Bundle', 'solicitor'),
      'slug' => 'so-widgets-bundle',
      'required'     => true,
    ],
    [ 
      'name' => esc_html__('Contact Form 7', 'solicitor'),
      'slug' => 'contact-form-7',
      'required'     => true,
    ],
    [ 
      'name' => esc_html__('Redux Framework', 'solicitor'),
      'slug'  => 'redux-framework',
      'required'           => true,
    ],
    [ 
      'name'             => esc_html__('imic Shortcodes', 'solicitor'),
      'slug'              => 'imic-shortcodes',
      'source'            => get_template_directory() . '/solicitor-framework' . '/tgm/plugins/imic-shortcodes.zip',
      'required'          => true,
    ],
    [ 
      'name'              => esc_html__('Revolution Slider', 'solicitor'),
      'slug'              => 'revslider',
      'source'            => get_template_directory() . '/solicitor-framework' . '/tgm/plugins/revslider.zip',
      'required'          => true,
    ],
  ];
 
  // Check if user is on the theme recommeneded plugins step and a demo was selected.
  if (
    isset( $_GET['step'] ) &&
    $_GET['step'] === 'import' &&
    isset( $_GET['import'] )
  ) {
 
  
  }
 
  return array_merge( $plugins, $theme_plugins );
}
add_filter( 'ocdi/register_plugins', 'ocdi_register_plugins' );

function ocdi_after_import_setup() {
    // Assign menus to their locations.
	$main_menu = get_term_by( 'name', 'Primary Menu', 'nav_menu' );
	$footer_menu = get_term_by( 'name', 'Footer Menu', 'nav_menu' );
 	if ( isset( $main_menu->term_id ) ) {
		set_theme_mod( 'nav_menu_locations', array(
			'primary-menu' => $main_menu->term_id,
			'footer-menu' => $footer_menu->term_id,
		));
	}
 
    // Assign front page and posts page (blog page).
    $front_page_id = get_page_by_title( 'Home' );
    $blog_page_id  = get_page_by_title( 'News List' );
 
    update_option( 'show_on_front', 'page' );
    update_option( 'page_on_front', $front_page_id->ID );
    update_option( 'page_for_posts', $blog_page_id->ID );
	
	// Update Widgets Switch to On
	$all_widgets_on = 'a:39:{s:6:"button";b:1;s:10:"google-map";b:1;s:5:"image";b:1;s:6:"slider";b:1;s:13:"post-carousel";b:1;s:6:"editor";b:1;s:8:"headline";b:1;s:3:"cta";b:1;s:7:"contact";b:1;s:8:"features";b:1;s:4:"hero";b:1;s:4:"icon";b:1;s:15:"carousel-widget";b:1;s:10:"image-grid";b:1;s:13:"layout-slider";b:1;s:11:"price-table";b:1;s:20:"social-media-buttons";b:1;s:14:"simple-masonry";b:1;s:8:"taxonomy";b:1;s:11:"testimonial";b:1;s:12:"alert-widget";b:1;s:5:"video";b:1;s:14:"counter-widget";b:1;s:22:"event-list-grid-widget";b:1;s:9:"hr-widget";b:1;s:22:"featured-blocks-widget";b:1;s:14:"iconbox-widget";b:1;s:10:"job-widget";b:1;s:18:"progressbar-widget";b:1;s:17:"posts-list-widget";b:1;s:15:"services-widget";b:1;s:28:"solicitor-news-ticker-widget";b:1;s:11:"tabs-widget";b:1;s:13:"spacer-widget";b:1;s:11:"team-widget";b:1;s:29:"solicitor-testimonials-widget";b:1;s:13:"toggle-widget";b:1;s:15:"timeline-widget";b:1;s:12:"video-widget";b:1;}';
	$all_widgets_on = unserialize($all_widgets_on);
	update_option('siteorigin_widgets_active', $all_widgets_on);
				
	// Update SiteOrigins Settings
	$siteorigins_settings = 'a:19:{s:10:"post-types";a:6:{i:0;s:4:"page";i:1;s:4:"post";i:2;s:5:"event";i:3;s:4:"team";i:4;s:11:"testimonial";i:5;s:7:"service";}s:22:"live-editor-quick-link";b:1;s:15:"parallax-motion";s:0:"";s:17:"sidebars-emulator";b:1;s:14:"display-teaser";b:1;s:13:"display-learn";b:1;s:10:"title-html";s:39:"<h3 class="widget-title">{{title}}</h3>";s:16:"add-widget-class";b:1;s:15:"bundled-widgets";b:0;s:19:"recommended-widgets";b:1;s:10:"responsive";b:1;s:13:"tablet-layout";b:0;s:12:"tablet-width";i:1024;s:12:"mobile-width";i:780;s:13:"margin-bottom";i:30;s:22:"margin-bottom-last-row";b:0;s:12:"margin-sides";i:30;s:20:"full-width-container";s:4:"body";s:12:"copy-content";b:1;}';
	$siteorigins_settings = unserialize($siteorigins_settings);
	update_option('siteorigin_panels_settings', $siteorigins_settings);
	
	// Revolution Slider Import
	if ( class_exists( 'RevSlider' ) ) {
		$slider_path = plugin_dir_path(__FILE__) . 'data/demo1/solicitor.zip';

		if ( file_exists( $slider_path ) ) {
			$slider = new RevSlider();
			$slider->importSliderFromPost( true, true, $slider_path );
		}
	}
}
add_action( 'ocdi/after_import', 'ocdi_after_import_setup' );
